@@ -30,15 +30,16 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = '0.04';
-our $url_query_base = 'http://www.wigle.net/gps/gps/main/confirmquery/';
-our $url_login = 'http://wigle.net/gps/gps/main/login';
+our $VERSION = '0.05';
+our $url_query_base = 'https://wigle.net/gps/gps/main/confirmquery/';
+our $url_login = 'https://wigle.net/gps/gps/main/login/';
 
 sub new {
   my $proto = shift;
   my $class = ref $proto || $proto;
   my $self = {};
   bless $self, $class;
+  $self->requests_redirectable(['GET', 'HEAD', 'POST']);
   return $self;
 }
 
